summaryrefslogtreecommitdiff
path: root/src/vm/interoputil.cpp
diff options
context:
space:
mode:
authorSwaroop Sridhar <Swaroop.Sridhar@microsoft.com>2019-01-18 09:24:41 -0800
committerGitHub <noreply@github.com>2019-01-18 09:24:41 -0800
commit732f892665343e84d04eea4478eccb459b385f55 (patch)
treea76fa9e8df71b776e414a0e73079974cf849d02b /src/vm/interoputil.cpp
parentec53bfdc54cf1b79730561c4a7f3c744090a400c (diff)
downloadcoreclr-732f892665343e84d04eea4478eccb459b385f55.tar.gz
coreclr-732f892665343e84d04eea4478eccb459b385f55.tar.bz2
coreclr-732f892665343e84d04eea4478eccb459b385f55.zip
Add Per-assembly Load Native Library callbacks (#21555)
Add Per-assembly Load Native Library callbacks This Change implements the Native Library resolution Call-backs proposed in https://github.com/dotnet/corefx/issues/32015
Diffstat (limited to 'src/vm/interoputil.cpp')
-rw-r--r--src/vm/interoputil.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/vm/interoputil.cpp b/src/vm/interoputil.cpp
index b84670ba3a..c70154d39c 100644
--- a/src/vm/interoputil.cpp
+++ b/src/vm/interoputil.cpp
@@ -897,9 +897,9 @@ void FillExceptionData(
#endif // CROSSGEN_COMPILE
//---------------------------------------------------------------------------
-//returns true if pImport has DefaultDllImportSearchPathsAttribute
-//if true, also returns dllImportSearchPathFlag and searchAssemblyDirectory values.
-BOOL GetDefaultDllImportSearchPathsAttributeValue(IMDInternalImport *pImport, mdToken token, DWORD * pDllImportSearchPathFlag)
+// If pImport has the DefaultDllImportSearchPathsAttribute,
+// set the value of the attribute in pDlImportSearchPathFlags and return true.
+BOOL GetDefaultDllImportSearchPathsAttributeValue(IMDInternalImport *pImport, mdToken token, DWORD * pDllImportSearchPathFlags)
{
CONTRACTL
{
@@ -929,7 +929,7 @@ BOOL GetDefaultDllImportSearchPathsAttributeValue(IMDInternalImport *pImport, md
args[0].InitEnum(SERIALIZATION_TYPE_U4, (ULONG)0);
ParseKnownCaArgs(ca, args, lengthof(args));
- *pDllImportSearchPathFlag = args[0].val.u4;
+ *pDllImportSearchPathFlags = args[0].val.u4;
return TRUE;
}